@@ -1,13 +1,11 @@
 """
-run_aggregator_service management command.
+reaggregate_course management command.
 
 Usage:
 
-    ./manage.py run_aggregator_service
+    ./manage.py reaggregate_course <course_key>
 
-Performs the actual aggregation.
-
-For continuous aggregation, set a cron job to run this task periodically.
+Reaggregates some specific course or a set of courses.
 """
 
 from __future__ import absolute_import, division, print_function, unicode_literals
@@ -58,7 +56,7 @@ class Command(BaseCommand):
         self.set_logging(options['verbosity'])
 
         if options['all']:
-            options['course_keys'] = BlockCompletion.objects.values_list('course_key').distinct()
+            options['course_keys'] = BlockCompletion.objects.values_list('context_key').distinct()
         CourseEnrollment = compat.course_enrollment_model()  # pylint: disable=invalid-name
         for course in options['course_keys']:
             if isinstance(course, six.string_types):
