@@ -38,3 +38,8 @@ def plugin_settings(settings):
         'COMPLETION_AGGREGATOR_CLEANUP_LOCK_TIMEOUT_SECONDS',
         settings.COMPLETION_AGGREGATOR_CLEANUP_LOCK_TIMEOUT_SECONDS,
     )
+
+    settings.COMPLETION_AGGREGATOR_AGGREGATE_UNRELEASED_BLOCKS = settings.ENV_TOKENS.get(
+        'COMPLETION_AGGREGATOR_AGGREGATE_UNRELEASED_BLOCKS',
+        settings.COMPLETION_AGGREGATOR_AGGREGATE_UNRELEASED_BLOCKS,
+    )
